@@ -4,7 +4,7 @@ import six
 import sqlalchemy as sa
 
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 
 
 class Column(sa.Column):
@@ -22,7 +22,7 @@ class Column(sa.Column):
         # Make strings and booleans not nullable by default
         if args:
             if (
-                any([bool_or_str(arg) for arg in args[0:2]]) or
+                any(bool_or_str(arg) for arg in args[0:2]) or
                 ('type' in kwargs and bool_or_str(kwargs['type']))
             ):
                 kwargs.setdefault('nullable', False)
@@ -97,10 +97,10 @@ class ModelConfigurator(object):
         """
         Assigns datetime auto now defaults
         """
-        if 'auto_now' in column.info and column.info['auto_now']:
+        if column.info.get('auto_now'):
             column.default = sa.schema.ColumnDefault(datetime.utcnow)
             if not column.server_default:
-                column.server_default = sa.func.now()
+                column.server_default = sa.schema.DefaultClause(sa.func.now())
 
     def assign_int_defaults(self, column):
         """
